betty.project.extension.requirement module - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.extension.requirement module

Provide requirements for Betty’s extension API.

class betty.project.extension.requirement.Dependencies

  Bases: `AllRequirements`

  Check a dependent’s dependency requirements.

  __init__(dependent: type[Extension])
  async summary() → Localizable

    Get the requirement’s human-readable summary.

class betty.project.extension.requirement.Dependents

  Bases: `Requirement`

  Check a dependency’s dependent requirements.

  __init__(dependency: Extension)
  async is_met() → bool

    Check if the requirement is met.

  async summary() → Localizable

    Get the requirement’s human-readable summary.